@@ -62,10 +62,11 @@ while [ $# -gt 0 ]; do
   shift
 done
 
-# get FPC version
-FPCVersion=$(fpc -v | grep 'Compiler version' | sed 's/.*\([0-9]\.[0-9]\.[0-9]\).*/\1/')
-echo "FPCVersion=$FPCVersion"
+# get date
+Date=`date +%Y%m%d`
+ChangeLogDate=`date --rfc-822`
 
+# get FPC version
 Arch=`dpkg --print-architecture`
 echo "debian architecture=$Arch"
 targetos=$Arch
@@ -88,22 +89,27 @@ else
     fi 
   fi 
 fi
+FPCVersion=$($ppcbin -v | grep version| sed 's/.*\([0-9]\+\.[0-9]\+\.[0-9]\+\).*/\1/')
 
-Date=`date +%Y%m%d`
-LazVersion=$(./get_lazarus_version.sh)$LazVersionPostfix
-SrcTGZ=lazarus-$LazVersion-$LazRelease.tar.gz
+# get Lazarus version
+LazVersion=$(./get_lazarus_version.sh)
+# get consistent major.minor.release version, to avoid dpkg install an older version
+if [ $(echo $LazVersion | egrep '^[^.]*\.[^.]*$') ]; then
+  LazVersion=${LazVersion}.0
+fi
+LazVersion=$LazVersion$LazVersionPostfix
+
+PkgName=lazarus-project
+SrcTGZ=$PkgName-$LazVersion-$LazRelease.tar.gz
 CurDir=`pwd`
-TmpDir=~/tmp/lazarus$LazVersion
-LazBuildDir=$TmpDir/lazarus_build
-LazDeb=$CurDir/lazarus_${LazVersion}-${LazRelease}_$Arch.deb
+TmpDir=~/tmp/$PkgName$LazVersion
+LazBuildDir=$TmpDir/${PkgName}_build
+LazDeb=$CurDir/${PkgName}_${LazVersion}-${LazRelease}_$Arch.deb
 DebianSrcDir=$CurDir/debian_lazarus
 EtcSrcDir=$CurDir/linux
 LazSrcDir=../..
 LazDestDir=$LazBuildDir/usr/share/lazarus/${LazVersion}
 LazDestDirInstalled=/usr/share/lazarus/${LazVersion}
- 
-FPCVersion=$($ppcbin -v | grep version| sed 's/.*\([0-9]\+\.[0-9]\+\.[0-9]\+\).*/\1/')
-ChangeLogDate=`date --rfc-822`
 
 echo "ppcbin=$ppcbin"
 echo "LazVersion=$LazVersion"
@@ -178,6 +184,7 @@ cat $DebianSrcDir/control$LCLWidgetset | \
       -e "s/LAZVERSION/$LazVersion/g" \
       -e "s/ARCH/$Arch/g" \
       -e "s/LAZSIZE/$LazSize/g" \
+      -e "s/PKGNAME/$PkgName/g" \
   > $LazBuildDir/DEBIAN/control
 
 # copyright and changelog files
